pub trait ToBEBytes<const N: usize> {
// Required method
fn to_be_bytes(&self) -> [u8; N];
}Expand description
Converts the value into a constant number of bytes
pub trait ToBEBytes<const N: usize> {
// Required method
fn to_be_bytes(&self) -> [u8; N];
}Converts the value into a constant number of bytes